@@ -1,7 +1,9 @@
 context("is_valid and the vectors")
 test_that("we can accept vectors", {
-  expect_equal(is_valid(c(1234567881, 1234567890, 9876543210, 2345678901)),
-               c(TRUE, FALSE, TRUE, FALSE))
+  expect_equal(
+    is_valid(c(1234567881, 1234567890, 9876543210, 2345678901)),
+    c(TRUE, FALSE, TRUE, FALSE)
+  )
 })
 
 context("is_valid and dodgy inputs")
